TandaMaster is a music player dedicated to playing tango music at milongas.

TandaMaster does not have playlists.  It has play*trees*, which makes it easy
to create and manipulate tandas.

It comes with a configurable gap between songs in a tanda.  The gap is precise,
as TandaMaster automatically detects silence at the beginning and the end of
the song, and takes it into account when playing the gap.

TandaMaster has a lock mode to prevent playback accidents during milongas.
While a tango is playing, pausing or switching to another song is prevented.
Changing the playing order during a cortina, however, is allowed.  And when the
cortina is interrupted, it will fade out gracefully.

Some other handy features include replay gain calculation, calculation of the
remaining time in the milonga, printing out song information on A4 sheets
(using LaTeX), and a stop-after-N-songs mode useful for classes.

TandaMaster has been used for more than a decade by several people (in
production, i.e. at milongas), and has performed nicely, but bear in mind that
this is still an unfinished project, and might remain this way forever.  Feel
free to contribute.

TandaMaster is a cross-platform program, but note that it has been developed on
Linux, and used almost exclusively with this OS.  A decade ago I successfully
created a Windows package, but since then some Linux-specific code (like
journald dependency) got in, so adapting it to Windows or Mac might take a
couple of hours of work.
